*-----------------------------------------------------------------------
*-- Program......: CENTER.PRG
*-- Programmer...: Jim Sare (CIS: 71562,413)
*-- Last Modified: 08/03/1995
*-- Notes........: Contains routines to:
*--              : Determine screen size in pixels.
*--              : Determine number of pixels/form unit (Turpin).
*--              : Determine window client area size in pixels.
*--              : Determine window size in pixels.
*--              : Center a form in the screen or the dBW MDI client area.
*--              : Move forms to any location faster than the Move method.
*--              : Determine dBW MDI client area size in form units.
*--              : Place UI objects on the dBW desktop.
*-- Written for..: dBASE for Windows (any version)
*-- Rev. History.: 03/17/1995 -- Original
*--              : 05/15/1995 -- Added MoveForm, SetAppClientControl,
*--              :               CenterAppClientControl procedures and
*--              :               changed <> to #.
*--              : 05/16/1995 -- Additional comments added.
*--              : 06/21/1995 -- Added and updated comments.
*--              : 07/31/1995 -- Fixed 'Calls' in SetAppClientControl coments.
*--              : 08/03/1995 -- Changed parameters to locals.
*-----------------------------------------------------------------------

PROCEDURE GetScreenX && Returns screen width in pixels
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine screen width in pixels.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 05/15/1995 -- Changed <> to #.
*--             : 06/21/1995 -- Updated comments.
*-- Calls.......: None
*-- Called by...: Any
*-- Usage.......: nScreenWidth = GetScreenX()
*-- Returns.....: Numeric -- Screen width in pixels.
*-- Parameters..: None
*-----------------------------------------------------------------------

	If Type("GetSystemMetrics") # "FP"
		extern CINT GetSystemMetrics(CINT) USER
	EndIf
	#define SM_CXSCREEN	0	&& Screen width in pixels

RETURN GetSystemMetrics(SM_CXSCREEN)
* EOP: GetScreenX

PROCEDURE GetScreenY && Returns screen height in pixels
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine screen height in pixels.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 05/15/1995 -- Changed <> to #.
*--             : 06/21/1995 -- Updated comments.
*-- Calls.......: None
*-- Called by...: Any
*-- Usage.......: nScreenHeight = GetScreenY()
*-- Returns.....: Numeric -- Screen height in pixels.
*-- Parameters..: None
*-----------------------------------------------------------------------

	If Type("GetSystemMetrics") # "FP"
		extern CINT GetSystemMetrics(CINT) USER
	endIf
	#define SM_CYSCREEN	1	&& Screen height in pixels

RETURN GetSystemMetrics(SM_CYSCREEN)
* EOP: GetScreenY

PROCEDURE UnitPixelsX(oForm) && Returns pixels/form unit (Turpin) on X axis
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine pixels/horizontal form unit (Turpin).
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: ClientPixWidth
*-- Called by...: Any
*-- Usage.......: nPixelsXUnit = UnitPixelsX(oFORM)
*-- Returns.....: Numeric -- Number of pixels/horizontal form unit.
*-- Parameters..: oForm = Object reference to the form.
*-----------------------------------------------------------------------

RETURN ClientPixWidth(oForm.hWND) / oForm.Width
* EOP: UnitPixelsX

PROCEDURE UnitPixelsY(oForm) && Returns pixels/form unit (Turpin) on Y axis
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine pixels/vertical form unit (Turpin).
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: ClientPixHeight
*-- Called by...: Any
*-- Usage.......: nPixelsYUnit = UnitPixelsY(oFORM)
*-- Returns.....: Numeric -- Number of pixels/vertical form unit.
*-- Parameters..: oForm = Object reference to the form.
*-----------------------------------------------------------------------

RETURN ClientPixHeight(oForm.hWND) / oForm.Height
* EOP: UnitPixelsY

PROCEDURE ClientPixWidth(nHandle) && Returns client area width in pixels
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine the width in pixels of the client area of a window.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 05/15/1995 -- Changed <> to #.
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: None. (WINAPI - GetClientRect)
*-- Called by...: Any
*-- Usage.......: nClientWidthPix = ClientPixWidth(f.hWND)
*-- Returns.....: Numeric
*-- Parameters..: nHandle = Valid Windows handle (hWND) to the window.
*-----------------------------------------------------------------------

	LOCAL cRect
	If Type("GetClientRect") # "FP"
		extern CVOID GetClientRect(CHANDLE, CPTR) USER
	EndIf
	#define GCR_WIDTH	5	&& Client area width
	#define WORD(s) Asc(SubStr(s,1)) + BitLShift(Asc(SubStr(s,2)),8)
	cRect = Space(8)
	GetClientRect(nHandle, cRect)
  
RETURN WORD(SubStr(cRect, GCR_WIDTH, 2))
* EOP: ClientPixWidth

PROCEDURE ClientPixHeight(nHandle) && Returns client area height in pixels
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine the height in pixels of the client area of a window.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 05/15/1995 -- Changed <> to #.
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: None. (WINAPI - GetClientRect)
*-- Called by...: Any
*-- Usage.......: nClientHeightPix = ClientPixHeight(f.hWND)
*-- Returns.....: Numeric
*-- Parameters..: nHandle = Valid Windows handle (hWND) to the window.
*-----------------------------------------------------------------------

	LOCAL cRect
	If Type("GetClientRect") # "FP"
		extern CVOID GetClientRect(CHANDLE, CPTR) USER
	EndIf
	#define GCR_HEIGHT	7	&& Client area height
	#define WORD(s) Asc(SubStr(s,1)) + BitLShift(Asc(SubStr(s,2)),8)
	cRect = Space(8)
	GetClientRect(nHandle, cRect)

RETURN WORD(SubStr(cRect, GCR_HEIGHT, 2))
* EOP: ClientPixHeight

PROCEDURE WindowPixWidth(nHandle) && Returns full window width in pixels
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine the width in pixels of a window.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 05/15/1995 -- Changed <> to #.
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: None. (WINAPI - GetWindowRect)
*-- Called by...: Any
*-- Usage.......: nWidthPix = WindowPixWidth(f.hWND)
*-- Returns.....: Numeric
*-- Parameters..: h = Valid Windows handle (hWND) to the window.
*-----------------------------------------------------------------------

	LOCAL cRect, nPixWidth
	If Type("GetWindowRect") # "FP"
		extern CVOID GetWindowRect(CHANDLE, CPTR) USER
	EndIf
	#define GWR_LEFT	1	&& Window left in pixels
	#define GWR_RIGHT	5	&& Window right in pixels
	#define	WORD(s) Asc(SubStr(s,1)) + BitLShift(Asc(SubStr(s,2)),8)
	cRect = Space(8)
	GetWindowRect(nHandle, cRect)
	nPixWidth = (WORD(SubStr(cRect, GWR_RIGHT, 2))) - (WORD(SubStr(cRect, GWR_LEFT, 2))) + 1
	If nPixWidth < 0  && Form's left side is off display screen
		nPixWidth = nPixWidth + 65536
	EndIf

RETURN nPixWidth
* EOP: WindowPixWidth

PROCEDURE WindowPixHeight(nHandle) && Returns full window height in pixels
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Determine the height in pixels of a window.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 05/15/1995 -- Changed <> to #.
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: None. (WINAPI - GetWindowRect)
*-- Called by...: Any
*-- Usage.......: nHeightPix = WindowPixHeight(f.hWND)
*-- Returns.....: Numeric
*-- Parameters..: nHandle = Valid Windows handle (hWND) to the window.
*-----------------------------------------------------------------------

	LOCAL cRect, nPixHeight
	If Type("GetWindowRect") # "FP"
		extern CVOID GetWindowRect(CHANDLE, CPTR) USER
	EndIf
	#define GWR_TOP		3	&& Window top in pixels
	#define GWR_BOTTOM	7	&& Window bottom in pixels
	#define	WORD(s) Asc(SubStr(s,1)) + BitLShift(Asc(SubStr(s,2)),8)
	cRect = Space(8)
	GetWindowRect(nHandle, cRect)
	nPixHeight = (WORD(SubStr(cRect, GWR_BOTTOM, 2))) - (WORD(SubStr(cRect, GWR_TOP, 2))) + 1
	If nPixHeight < 0 && Form's top side is off display screen
		nPixHeight = nPixHeight + 65536
	EndIf
 
RETURN nPixHeight
* EOP: WindowPixHeight

PROCEDURE CenterForm(oForm) && Centers MDI form to dBW client area or non-MDI form to screen area
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Center a MDI form to the dBW client area or non-MDI form
*--             : to the screen area. This is best accomplished by setting
*--             : the f.Top = -300 in the form's header and then call
*--             : CenterForm(f) in the form's OnOpen to center the form.
*--             : Provides quickest method to center a form for 2 reasons:
*--             : 1. Uses the WINAPI call SetWindowPos which only draws the
*--             :  form once on the screen.
*--             : 2. Centers the form directly based on the form's size
*--             :  relative to the dBW client area size (MDI), or screen area
*--             :  size (non-MDI).
*--             : This procedure can be used with modeless and modal forms.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 03/17/1995 -- Original
*--             : 05/15/1995 -- Changed <> to #.
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: WindowPixWidth, WindowPixHeight
*--             : WINAPI: GetParent, SetWindowPos, UpdateWindow
*-- Called by...: Any
*-- Usage.......: In the WFM header:
*--             : f = New MyForm    && Substitute the ClassName of your form.
*--             : f.Top = -300      && Override class Top to open off screen.
*--             : f.OnOpen = {; CenterForm(this)}  && Center form in OnOpen.
*--             : * f.MDI = .F.     && if opened with ReadModal().
*--             : f.Open()          && Or f.ReadModal().
*--             : RETURN            && Prevent opening 2 copies of form.
*--             : * End Header...
*-- Returns.....: None
*-- Parameters..: oForm = Object reference to the form object.
*-----------------------------------------------------------------------

	LOCAL nThehWND, nNewLeft, nNewTop
	If oForm.MDI
		If Type("GetParent") # "FP"
			extern CHANDLE GetParent(CHANDLE) USER
		EndIf
		nThehWND = GetParent(oForm.hWND) && Get dBW MDIClient window
		* Compute the position to center the form horizontally
		nNewLeft = ( (WindowPixWidth(nThehWND) - WindowPixWidth(oForm.hWND)) / 2 )
		* Compute the position to center the form vertically
		nNewTop = ( (WindowPixHeight(nThehWND) - WindowPixHeight(oForm.hWND)) / 2 )
		If nNewLeft < 0 .OR. nNewLeft > WindowPixWidth(nThehWND)
			nNewLeft = 0 && Form is wider than dBW MDIClient window
		EndIf
		If nNewTop < 0 .OR. nNewTop > WindowPixHeight(nThehWND)
			nNewTop = 0 && Form is taller than dBW MDIClient window
		EndIf
	Else
		nNewLeft = ( (GetScreenX() - WindowPixWidth(oForm.hWND)) / 2 )
		nNewTop = ( (GetScreenY() - WindowPixHeight(oForm.hWND)) / 2 )
		If nNewLeft < 0 .OR. nNewLeft > GetScreenX()
			nNewLeft = 0 && Form is wider than screen
		EndIf
		If nNewTop < 0 .OR. nNewTop > GetScreenY()
			nNewTop = 0 && Form is taller than screen
		EndIf
	EndIf
	* Using SetWindowPos causes the form to only be redrawn once as 
	* opposed to setting the Top & Left properties individually or 
	* using the Move() method which causes the form to be redrawn 
	* twice.
	If Type("SetWindowPos") # "FP"
		extern CWORD SetWindowPos(CHANDLE, CHANDLE, CINT, CINT, CINT, CINT, CINT) USER
	EndIf
	If Type("UpdateWindow") # "FP"
		extern CVOID UpdateWindow(CHANDLE) USER
	EndIf
	#ifndef	SWP_NOSIZE
		#define	SWP_NOSIZE	1	&& Don't resize the form
	#endif
	SetWindowPos(oForm.hWND, 0, nNewLeft, nNewTop, 0, 0, SWP_NOSIZE)
	UpdateWindow(oForm.hWND)

RETURN
* EOP: CenterForm

PROCEDURE MoveForm(oForm, nLeft, nTop) && Moves a form to a new position.
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: MoveForm is faster than dBW FORM.Move() method. It also
*--             : prevents the form from being drawn twice.
*--             : This procedure can be used with any dBW form (modeless,
*--             : modal, MDI or SDI).
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 05/15/1995 -- Original
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: UnitPixelsX, UnitPixelsY
*--             : WINAPI: SetWindowPos, UpdateWindow
*-- Called by...: Any
*-- Usage.......: To provide a faster form open, in the WFM header:
*--             : f = New MyForm    && Substitute the ClassName of your form.
*--             : f.Top = -300      && Override class Top to open off screen.
*--             : f.OnOpen = {; MoveForm(this, 4, 2)}  && Move form in OnOpen.
*--             : * f.MDI = .F.     && if opened with ReadModal().
*--             : f.Open()          && Or f.ReadModal().
*--             : RETURN            && Prevent opening 2 copies of form.
*--             : * End Header...
*--             : Or, to move the form from anywhere in your program:
*--             : MoveForm(FORM, 4, 2)
*-- Returns.....: None
*-- Parameters..: oForm = Object reference to the form object to be moved.
*--             : nLeft = New Left position for the form in form units (Turpins).
*--             : nTop = New Top position for the form in form units (Turpins).
*-----------------------------------------------------------------------

	LOCAL nNewLeft, nNewTop
	nNewLeft = nLeft * UnitPixelsX(oForm)
	nNewTop = nTop * UnitPixelsY(oForm)
	If Type("SetWindowPos") # "FP"
		extern CWORD SetWindowPos(CHANDLE, CHANDLE, CINT, CINT, CINT, CINT, CINT) USER
	EndIf
	If Type("UpdateWindow") # "FP"
		extern CVOID UpdateWindow(CHANDLE) USER
	EndIf
	#ifndef	SWP_NOSIZE
		#define	SWP_NOSIZE	1	&& Don't resize the form
	#endif
	SetWindowPos(oForm.hWND, 0, nNewLeft, nNewTop, 0, 0, SWP_NOSIZE)
	UpdateWindow(oForm.hWND)

RETURN
* EOP: MoveForm

PROCEDURE MDIClientUnitWidth(oForm) && Returns MDIClient width in form units
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: This procedure calculates and returns the width of the
*--             : dBW MDIClient window in form units (Turpins).
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 05/16/1995 -- Original
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: ClientPixWidth, UnitPixelsX
*--             : WINAPI: GetParent
*-- Called by...: Any
*-- Usage.......: nWidth = MDIClientUnitWidth(FORM)
*-- Returns.....: Numeric - The width of the MDIClient window in form units.
*-- Parameters..: oForm = Object reference to a form object.
*-----------------------------------------------------------------------

	If Type("GetParent") # "FP"
		extern CHANDLE GetParent(CHANDLE) USER
	EndIf
	*-- Calculate the size of the MDIClient window in form units
	RETURN ClientPixWidth(GetParent(oForm.hWND)) / UnitPixelsX(oForm)

* EOP: MDIClientUnitWidth

PROCEDURE MDIClientUnitHeight(oForm) && Returns MDIClient height in form units
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: This procedure calculates and returns the height of the
*--             : dBW MDIClient window in form units (Turpins).
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 05/16/1995 -- Original
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: ClientPixHeight, UnitPixelsY
*--             : WINAPI: GetParent
*-- Called by...: Any
*-- Usage.......: nWidth = MDIClientUnitHeight(FORM)
*-- Returns.....: Numeric - The height of the MDIClient window in form units.
*-- Parameters..: oForm = Object reference to a form.
*-----------------------------------------------------------------------

	If Type("GetParent") # "FP"
		extern CHANDLE GetParent(CHANDLE) USER
	EndIf
	*-- Calculate the size of the MDIClient window in form units
	RETURN ClientPixHeight(GetParent(oForm.hWND)) / UnitPixelsY(oForm)

* EOP: MDIClientUnitHeight

PROCEDURE CenterAppClientControl(oCtlRef) && Center a dBW UI object in dBW client window
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 06/21/1995
*-- Notes.......: Will center a dBW UI object such as an Image or Text object
*--             : in the dBW MDIClient window.
*--             : 1. The MDIClient window does not support colored pens for
*--             :    drawing text. It only supports black on white. So, no
*--             :    matter what you set Text.ColorNormal to, it will display
*--             :    in black and white when the Text object is moved to the
*--             :    dBW MDIClient window.
*--             : 2. You cannot move or resize the controls once they are
*--             :    assigned to the MDIClient window. If you attempt to move
*--             :    or resize the controls, they will disappear.
*--             : 3. You can code event handlers and methods for controls
*--             :    placed in the MDIClient window although this has not been
*--             :    thoroughly tested at this time.
*--             : 4. The form on which the controls were created must remain
*--             :    open. If you close the form on which the controls
*--             :    originated after moving the controls to the MDIClient
*--             :    window, the controls will disappear from the MDIClient
*--             :    window.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 05/15/1995 -- Original
*--             : 05/16/1995 -- Additional comments added.
*--             : 06/21/1995 -- Updated comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: WindowPixWidth, WindowPixHeight
*--             : WINAPI: GetParent, SetParent, SetWindowPos, UpdateWindow
*-- Called by...: Any
*-- Usage.......: SetAppClientControl(FORM.Image1)
*--             : SetAppClientControl(FORM.Text1)
*-- Returns.....: None
*-- Parameters..: oCtlRef = Object reference of control to be placed in
*--             : MDIClient window.
*-----------------------------------------------------------------------

	LOCAL nThehWND, nNewLeft, nNewTop
	If Type("GetParent") # "FP"
		extern CHANDLE GetParent(CHANDLE) USER
	EndIf
	nThehWND = GetParent(oCtlRef.Parent.hWND) && Get dBW MDIClient window
	* Compute the position to center the image horizontally
	nNewLeft = ( (WindowPixWidth(nThehWND) - WindowPixWidth(oCtlRef.hWND)) / 2 )
	* Compute the position to center the image vertically
	nNewTop = ( (WindowPixHeight(nThehWND) - WindowPixHeight(oCtlRef.hWND)) / 2 )
	If nNewLeft < 0 .OR. nNewLeft > WindowPixWidth(nThehWND)
		nNewLeft = 0 && Image is wider than dBW MDIClient window
	EndIf
	If nNewTop < 0 .OR. nNewTop > WindowPixHeight(nThehWND)
		nNewTop = 0 && Image is taller than dBW MDIClient window
	EndIf
	If Type("SetWindowPos") # "FP"
		extern CWORD SetWindowPos(CHANDLE, CHANDLE, CINT, CINT, CINT, CINT, CINT) USER
	EndIf
	If Type("SetParent") # "FP"
		extern CHANDLE SetParent(CHANDLE, CHANDLE) USER
	EndIf
	If Type("UpdateWindow") # "FP"
		extern CVOID UpdateWindow(CHANDLE) USER
	EndIf
	#ifndef	SWP_NOSIZE
		#define	SWP_NOSIZE	1	&& Don't resize the image
	#endif
	SetWindowPos(oCtlRef.hWND, 0, nNewLeft, nNewTop, 0, 0, SWP_NOSIZE)
	SetParent(oCtlRef.hWND, nThehWND) && Make the MDIClient window the parent of object
	UpdateWindow(oCtlRef.hWND)       && Paint quickly

RETURN
* EOP: CenterAppClientControl

PROCEDURE SetAppClientControl(oCtlRef) && Place a dBW UI object in dBW client window
*-----------------------------------------------------------------------
*-- Programmer..: Jim Sare (CIS: 71562,413)
*-- Date........: 07/31/1995
*-- Notes.......: Will place a dBW UI object such as an Image or Text object
*--             : in the dBW MDIClient window.
*--             : The positioning of the controls in the MDIClient window
*--             : is relative to the upper-left corner of the MDIClient
*--             : window. So, when using SetParent to move the control(s)
*--             : from the form to the MDIClient window, the controls(s)
*--             : will be positioned in the MDIClient window in the same
*--             : position relative to the top-left corner of the MDIClient
*--             : window as they were in on the original form at the time
*--             : of the SetParent call.
*--             : See CenterAppClientControl for additional notes on using
*--             : this procedure.
*-- Written for.: dBASE for Windows (any version)
*-- Rev. History: 05/15/1995 -- Original
*--             : 05/16/1995 -- Additional comments added.
*--             : 06/21/1995 -- Updated comments.
*--             : 07/31/1995 -- Fixed 'Calls' in comments.
*--             : 08/03/1995 -- Changed parameters to locals.
*-- Calls.......: None
*--             : WINAPI: GetParent, SetParent, UpdateWindow
*-- Called by...: Any
*-- Usage.......: SetAppClientControl(FORM.Image1)
*--             : SetAppClientControl(FORM.Text1)
*-- Returns.....: None
*-- Parameters..: oCtlRef = Object reference of control to be placed in
*--             : MDIClient window.
*-----------------------------------------------------------------------

	LOCAL nThehWND
	If Type("GetParent") # "FP"
		extern CHANDLE GetParent(CHANDLE) USER
	EndIf
	If Type("UpdateWindow") # "FP"
		extern CVOID UpdateWindow(CHANDLE) USER
	EndIf
	If Type("SetParent") # "FP"
		extern CHANDLE SetParent(CHANDLE, CHANDLE) USER
	EndIf
	nThehWND = GetParent(oCtlRef.Parent.hWND) && Get dBW MDIClient window
	SetParent(oCtlRef.hWND, nThehWND) && Make the MDIClient window the parent of oCtlRef
	UpdateWindow(oCtlRef.hWND)       && Paint quickly

RETURN
* EOP: SetAppClientControl

* EOF: CENTER.PRG
